==> DQScriptsDemo_0_3.zip: DQScriptsDemo_0_3/rgss-lib/dq/skill/Skill_Facade.rb <==
#==============================================================================
#  Skill_Facade
#------------------------------------------------------------------------------
# XLp`oh
#==============================================================================

module Skill_Facade
  @@last_result = nil

  module_function

  #--------------------------------------------------------------------------
  # ŌɎs`oh̕ԋpl
  #--------------------------------------------------------------------------
  def last_result
    return @@last_result
  end

  #--------------------------------------------------------------------------
  # XLgp
  #--------------------------------------------------------------------------
  def use_skill(skill,owner_actor,target_actors)
    @@last_result = false
    target_actors.each do |actor|
      @@last_result |= actor.skill_effect(owner_actor, skill)
    end
    # XLgpꂽꍇ
    if @@last_result
      # XL̎gp SE t
      $game_system.se_play(skill.menu_se)
      # SP 
      owner_actor.sp -= skill.sp_cost
    end
    return @@last_result
  end

  #--------------------------------------------------------------------------
  # AN^[̎ĂXL̈ꗗ擾
  #--------------------------------------------------------------------------
  def actor_skills(actor)
    @@last_result = []
    actor.skills.each do |id|
      skill = $data_skills[id]
      if not skill.nil?
        @@last_result.push(skill)
      end
    end
    return @@last_result
  end
  #--------------------------------------------------------------------------
  # AN^[̎ĂʏXL̈ꗗ擾
  #--------------------------------------------------------------------------
  def actor_normal_skills(actor)
    @@last_result = []
    actor.skills.each do |id|
      skill = $data_skills[id]
      if (not skill.nil?) and [0,2].include?(skill.occasion)
        @@last_result.push(skill)
      end
    end
    return @@last_result
  end
  #--------------------------------------------------------------------------
  # AN^[̎Ă퓬XL̈ꗗ擾
  #--------------------------------------------------------------------------
  def actor_battle_skills(actor)
    @@last_result = []
    actor.skills.each do |id|
      skill = $data_skills[id]
      if (not skill.nil?) and [0,1].include?(skill.occasion)
        @@last_result.push(skill)
      end
    end
    return @@last_result
  end

  #--------------------------------------------------------------------------
  # AN^[̃NXo\̂XL̈ꗗ擾
  #--------------------------------------------------------------------------
  def actor_class_skills(actor)
    @@last_result = []
    $data_classes[actor.class_id].learnings.each do |learning|
      id = learning.skill_id
      skill = $data_skills[id]
      if not skill.nil?
        @@last_result.push(skill)
      end
    end
    return @@last_result
  end

  #--------------------------------------------------------------------------
  # AN^[̃NXo\̂ʏXL̈ꗗ擾
  #--------------------------------------------------------------------------
  def actor_class_normal_skills(actor)
    @@last_result = []
    $data_classes[actor.class_id].learnings.each do |learning|
      id = learning.skill_id
      skill = $data_skills[id]
      if (not skill.nil?) and [0,2].include?(skill.occasion)
        @@last_result.push(skill)
      end
    end
    return @@last_result
  end
end

==> DQScriptsDemo_0_3_1.zip: DQScriptsDemo_0_3_1/rgss-lib/dq/skill/Skill_Facade.rb <==
#==============================================================================
#  Skill_Facade
#------------------------------------------------------------------------------
# XLp`oh
#==============================================================================

module Skill_Facade
  @@last_result = nil
  
  module_function
  
  #--------------------------------------------------------------------------
  # ŌɎs`oh̕ԋpl
  #--------------------------------------------------------------------------
  def last_result
    return @@last_result
  end
  
  #--------------------------------------------------------------------------
  # XLgp
  #--------------------------------------------------------------------------
  def use_skill(skill,owner_actor,target_actors)
    @@last_result = false
    target_actors.each do |actor|
      @@last_result |= actor.skill_effect(owner_actor, skill)
    end
    # XLgpꂽꍇ
    if @@last_result
      # XL̎gp SE t
      $game_system.se_play(skill.menu_se)
      # SP 
      owner_actor.sp -= skill.sp_cost
    end
    return @@last_result
  end
  
  #--------------------------------------------------------------------------
  # AN^[̎ĂXL̈ꗗ擾
  #--------------------------------------------------------------------------
  def actor_skills(actor)
    @@last_result = []
    actor.skills.each do |id|
      skill = $data_skills[id]
      if not skill.nil?
        @@last_result.push(skill)
      end
    end
    return @@last_result
  end
  
  NORMAL_SKILL_OCCASION = [0,2]
  BATTLE_SKILL_OCCASION = [0,1]
  
  #--------------------------------------------------------------------------
  # AN^[̎ĂʏXL̈ꗗ擾
  #--------------------------------------------------------------------------
  def actor_normal_skills(actor)
    @@last_result = []
    actor.skills.each do |id|
      skill = $data_skills[id]
      if (not skill.nil?) and NORMAL_SKILL_OCCASION.include?(skill.occasion)
        @@last_result.push(skill)
      end
    end
    return @@last_result
  end
  #--------------------------------------------------------------------------
  # AN^[̎Ă퓬XL̈ꗗ擾
  #--------------------------------------------------------------------------
  def actor_battle_skills(actor)
    @@last_result = []
    actor.skills.each do |id|
      skill = $data_skills[id]
      if (not skill.nil?) and BATTLE_SKILL_OCCASION.include?(skill.occasion)
        @@last_result.push(skill)
      end
    end
    return @@last_result
  end
  
  #--------------------------------------------------------------------------
  # AN^[̃NXo\̂XL̈ꗗ擾
  #--------------------------------------------------------------------------
  def actor_class_skills(actor)
    @@last_result = []
    $data_classes[actor.class_id].learnings.each do |learning|
      id = learning.skill_id
      skill = $data_skills[id]
      if not skill.nil?
        @@last_result.push(skill)
      end
    end
    return @@last_result
  end
  
  #--------------------------------------------------------------------------
  # AN^[̃NXo\̂ʏXL̈ꗗ擾
  #--------------------------------------------------------------------------
  def actor_class_normal_skills(actor)
    @@last_result = []
    $data_classes[actor.class_id].learnings.each do |learning|
      id = learning.skill_id
      skill = $data_skills[id]
      if (not skill.nil?) and [0,2].include?(skill.occasion)
        @@last_result.push(skill)
      end
    end
    return @@last_result
  end
end
